@@ -48,12 +48,25 @@ async def tcp_echo_client(message, loop,host,port,usereverseproxy,microserviceid
         message="GET %s\n\n" % geturl 
 
     reader, writer = await asyncio.open_connection(host, port, loop=loop)
+    try:
+      mystr=str.encode(message)
+      writer.write(mystr)
+      datam=''
+      while True:
+        data = await reader.read(1024)
+      #  print(data)
+        datam=datam+data.decode("utf-8")
+       # print(datam)
+        if not data:
+           break
         
-    mystr=str.encode(message)
-    writer.write(mystr)
-    data = await reader.read(32768)
-    prediction=("%s" % (data.decode()))
-    writer.close()
+        await writer.drain()
+   #   print(datam)  
+      prediction=("%s" % (datam))
+      writer.close()
+    except Exception as e:
+      print(e)
+      return e
     
     return prediction
 
